==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkPLYWriter.java <==
// java wrapper for vtkPLYWriter object
//

package vtk;
import vtk.*;

public class vtkPLYWriter extends vtkWriter
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDataByteOrder_2(int id0);
  public void SetDataByteOrder(int id0)
    { SetDataByteOrder_2(id0); }

  private native int GetDataByteOrderMinValue_3();
  public int GetDataByteOrderMinValue()
    { return GetDataByteOrderMinValue_3(); }

  private native int GetDataByteOrderMaxValue_4();
  public int GetDataByteOrderMaxValue()
    { return GetDataByteOrderMaxValue_4(); }

  private native int GetDataByteOrder_5();
  public int GetDataByteOrder()
    { return GetDataByteOrder_5(); }

  private native void SetDataByteOrderToBigEndian_6();
  public void SetDataByteOrderToBigEndian()
    { SetDataByteOrderToBigEndian_6(); }

  private native void SetDataByteOrderToLittleEndian_7();
  public void SetDataByteOrderToLittleEndian()
    { SetDataByteOrderToLittleEndian_7(); }

  private native void SetColorMode_8(int id0);
  public void SetColorMode(int id0)
    { SetColorMode_8(id0); }

  private native int GetColorMode_9();
  public int GetColorMode()
    { return GetColorMode_9(); }

  private native void SetColorModeToDefault_10();
  public void SetColorModeToDefault()
    { SetColorModeToDefault_10(); }

  private native void SetColorModeToUniformCellColor_11();
  public void SetColorModeToUniformCellColor()
    { SetColorModeToUniformCellColor_11(); }

  private native void SetColorModeToUniformPointColor_12();
  public void SetColorModeToUniformPointColor()
    { SetColorModeToUniformPointColor_12(); }

  private native void SetColorModeToUniformColor_13();
  public void SetColorModeToUniformColor()
    { SetColorModeToUniformColor_13(); }

  private native void SetColorModeToOff_14();
  public void SetColorModeToOff()
    { SetColorModeToOff_14(); }

  private native void SetArrayName_15(String id0);
  public void SetArrayName(String id0)
    { SetArrayName_15(id0); }

  private native String GetArrayName_16();
  public String GetArrayName()
    { return GetArrayName_16(); }

  private native void SetComponent_17(int id0);
  public void SetComponent(int id0)
    { SetComponent_17(id0); }

  private native int GetComponentMinValue_18();
  public int GetComponentMinValue()
    { return GetComponentMinValue_18(); }

  private native int GetComponentMaxValue_19();
  public int GetComponentMaxValue()
    { return GetComponentMaxValue_19(); }

  private native int GetComponent_20();
  public int GetComponent()
    { return GetComponent_20(); }

  private native void SetLookupTable_21(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_21(id0); }

  private native long GetLookupTable_22();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_22();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetColor_23(char id0,char id1,char id2);
  public void SetColor(char id0,char id1,char id2)
    { SetColor_23(id0,id1,id2); }

  private native byte[] GetColor_24();
  public byte[] GetColor()
    { return GetColor_24(); }

  private native long GetInput_25();
  public vtkPolyData GetInput() {
    long temp = GetInput_25();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_26(int id0);
  public vtkPolyData GetInput(int id0) {
    long temp = GetInput_26(id0);

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFileName_27(String id0);
  public void SetFileName(String id0)
    { SetFileName_27(id0); }

  private native String GetFileName_28();
  public String GetFileName()
    { return GetFileName_28(); }

  private native void SetFileType_29(int id0);
  public void SetFileType(int id0)
    { SetFileType_29(id0); }

  private native int GetFileTypeMinValue_30();
  public int GetFileTypeMinValue()
    { return GetFileTypeMinValue_30(); }

  private native int GetFileTypeMaxValue_31();
  public int GetFileTypeMaxValue()
    { return GetFileTypeMaxValue_31(); }

  private native int GetFileType_32();
  public int GetFileType()
    { return GetFileType_32(); }

  private native void SetFileTypeToASCII_33();
  public void SetFileTypeToASCII()
    { SetFileTypeToASCII_33(); }

  private native void SetFileTypeToBinary_34();
  public void SetFileTypeToBinary()
    { SetFileTypeToBinary_34(); }

  private native void SetTextureCoordinatesName_35(int id0);
  public void SetTextureCoordinatesName(int id0)
    { SetTextureCoordinatesName_35(id0); }

  private native int GetTextureCoordinatesNameMinValue_36();
  public int GetTextureCoordinatesNameMinValue()
    { return GetTextureCoordinatesNameMinValue_36(); }

  private native int GetTextureCoordinatesNameMaxValue_37();
  public int GetTextureCoordinatesNameMaxValue()
    { return GetTextureCoordinatesNameMaxValue_37(); }

  private native int GetTextureCoordinatesName_38();
  public int GetTextureCoordinatesName()
    { return GetTextureCoordinatesName_38(); }

  private native void SetTextureCoordinatesNameToUV_39();
  public void SetTextureCoordinatesNameToUV()
    { SetTextureCoordinatesNameToUV_39(); }

  private native void SetTextureCoordinatesNameToTextureUV_40();
  public void SetTextureCoordinatesNameToTextureUV()
    { SetTextureCoordinatesNameToTextureUV_40(); }

  private native void AddComment_41(String id0);
  public void AddComment(String id0)
    { AddComment_41(id0); }

  public vtkPLYWriter() { super(); }

  public vtkPLYWriter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-4-armv7h.pkg.tar.xz: vtk/vtkPLYWriter.java <==
// java wrapper for vtkPLYWriter object
//

package vtk;
import vtk.*;

public class vtkPLYWriter extends vtkWriter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDataByteOrder_2(int id0);
  public void SetDataByteOrder(int id0)
    { SetDataByteOrder_2(id0); }

  private native int GetDataByteOrderMinValue_3();
  public int GetDataByteOrderMinValue()
    { return GetDataByteOrderMinValue_3(); }

  private native int GetDataByteOrderMaxValue_4();
  public int GetDataByteOrderMaxValue()
    { return GetDataByteOrderMaxValue_4(); }

  private native int GetDataByteOrder_5();
  public int GetDataByteOrder()
    { return GetDataByteOrder_5(); }

  private native void SetDataByteOrderToBigEndian_6();
  public void SetDataByteOrderToBigEndian()
    { SetDataByteOrderToBigEndian_6(); }

  private native void SetDataByteOrderToLittleEndian_7();
  public void SetDataByteOrderToLittleEndian()
    { SetDataByteOrderToLittleEndian_7(); }

  private native void SetColorMode_8(int id0);
  public void SetColorMode(int id0)
    { SetColorMode_8(id0); }

  private native int GetColorMode_9();
  public int GetColorMode()
    { return GetColorMode_9(); }

  private native void SetColorModeToDefault_10();
  public void SetColorModeToDefault()
    { SetColorModeToDefault_10(); }

  private native void SetColorModeToUniformCellColor_11();
  public void SetColorModeToUniformCellColor()
    { SetColorModeToUniformCellColor_11(); }

  private native void SetColorModeToUniformPointColor_12();
  public void SetColorModeToUniformPointColor()
    { SetColorModeToUniformPointColor_12(); }

  private native void SetColorModeToUniformColor_13();
  public void SetColorModeToUniformColor()
    { SetColorModeToUniformColor_13(); }

  private native void SetColorModeToOff_14();
  public void SetColorModeToOff()
    { SetColorModeToOff_14(); }

  private native void SetArrayName_15(String id0);
  public void SetArrayName(String id0)
    { SetArrayName_15(id0); }

  private native String GetArrayName_16();
  public String GetArrayName()
    { return GetArrayName_16(); }

  private native void SetComponent_17(int id0);
  public void SetComponent(int id0)
    { SetComponent_17(id0); }

  private native int GetComponentMinValue_18();
  public int GetComponentMinValue()
    { return GetComponentMinValue_18(); }

  private native int GetComponentMaxValue_19();
  public int GetComponentMaxValue()
    { return GetComponentMaxValue_19(); }

  private native int GetComponent_20();
  public int GetComponent()
    { return GetComponent_20(); }

  private native void SetLookupTable_21(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_21(id0); }

  private native long GetLookupTable_22();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_22();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetColor_23(char id0,char id1,char id2);
  public void SetColor(char id0,char id1,char id2)
    { SetColor_23(id0,id1,id2); }

  private native byte[] GetColor_24();
  public byte[] GetColor()
    { return GetColor_24(); }

  private native long GetInput_25();
  public vtkPolyData GetInput() {
    long temp = GetInput_25();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_26(int id0);
  public vtkPolyData GetInput(int id0) {
    long temp = GetInput_26(id0);

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFileName_27(String id0);
  public void SetFileName(String id0)
    { SetFileName_27(id0); }

  private native String GetFileName_28();
  public String GetFileName()
    { return GetFileName_28(); }

  private native void SetFileType_29(int id0);
  public void SetFileType(int id0)
    { SetFileType_29(id0); }

  private native int GetFileTypeMinValue_30();
  public int GetFileTypeMinValue()
    { return GetFileTypeMinValue_30(); }

  private native int GetFileTypeMaxValue_31();
  public int GetFileTypeMaxValue()
    { return GetFileTypeMaxValue_31(); }

  private native int GetFileType_32();
  public int GetFileType()
    { return GetFileType_32(); }

  private native void SetFileTypeToASCII_33();
  public void SetFileTypeToASCII()
    { SetFileTypeToASCII_33(); }

  private native void SetFileTypeToBinary_34();
  public void SetFileTypeToBinary()
    { SetFileTypeToBinary_34(); }

  private native void SetTextureCoordinatesName_35(int id0);
  public void SetTextureCoordinatesName(int id0)
    { SetTextureCoordinatesName_35(id0); }

  private native int GetTextureCoordinatesNameMinValue_36();
  public int GetTextureCoordinatesNameMinValue()
    { return GetTextureCoordinatesNameMinValue_36(); }

  private native int GetTextureCoordinatesNameMaxValue_37();
  public int GetTextureCoordinatesNameMaxValue()
    { return GetTextureCoordinatesNameMaxValue_37(); }

  private native int GetTextureCoordinatesName_38();
  public int GetTextureCoordinatesName()
    { return GetTextureCoordinatesName_38(); }

  private native void SetTextureCoordinatesNameToUV_39();
  public void SetTextureCoordinatesNameToUV()
    { SetTextureCoordinatesNameToUV_39(); }

  private native void SetTextureCoordinatesNameToTextureUV_40();
  public void SetTextureCoordinatesNameToTextureUV()
    { SetTextureCoordinatesNameToTextureUV_40(); }

  private native void AddComment_41(String id0);
  public void AddComment(String id0)
    { AddComment_41(id0); }

  public vtkPLYWriter() { super(); }

  public vtkPLYWriter(long id) { super(id); }
  public native long   VTKInit();

}
